虎口脱险 (豆瓣)
Description: 虎口脱险电影简介和剧情介绍,虎口脱险影评、图片、预告片、影讯、论坛、在线购票
Keywords: 虎口脱险,La grande vadrouille,虎口脱险影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.210豆瓣电影Top250

# 虎口脱险 La grande vadrouille (1966)

导演: 热拉尔·乌里
编剧: 热拉尔·乌里 / 达妮埃尔·汤普森 / 马塞尔·朱利安 / 乔治·塔贝 / 安德烈·塔贝
主演: 路易·德·菲奈斯 / 布尔维尔 / 克劳迪奥·布鲁克 / 安德丽·帕里西 / 科莱特·布罗塞 / 迈克·马歇尔 / 玛丽·马凯 / 皮埃尔·贝尔坦 / 本诺·施特岑巴赫 / 玛丽·杜布瓦 / 特里-托马斯 / 西戈德·拉普 / 赖因哈德·科尔德霍夫 / 赫尔穆特·施奈德 / 保罗·普雷博伊斯特 / 汉斯·迈尔 / 居伊·格罗索 / 米歇尔·莫多 / 彼得·雅各布 / 吕迪·勒努瓦 / 诺埃尔·达扎尔 / 皮埃尔·鲁塞尔 / 皮埃尔·巴斯蒂安 / 雅克·萨布隆 / 玛格·阿夫里尔 / 雅克·博杜因 / 加布里埃尔·戈班 / 保罗·梅塞 / 亨利·热内斯
类型: 喜剧 / 战争
制片国家/地区: 法国 / 英国
语言: 法语 / 英语 / 德语
上映日期: 1966-12-08(法国)
片长: 132分钟 / 124分钟(蓝光修复版) / 122分钟(4K修复版)
又名: 横冲直撞出重围(港) / 大進擊(台) / Don't Look Now... We're Being Shot At!
IMDb: tt0060474
豆瓣评分
引用
8.9
241302人评价
5星
57.4%
4星
32.9%
3星
8.6%
2星
0.8%
1星
0.3%
好于 98% 喜剧片
好于 98% 战争片
想看 看过
评价:
推荐

## 虎口脱险的剧情简介 · · · · · ·

二战期间，英国一架飞机在执行轰炸任务中，被德军击中，几名英国士兵被迫跳伞逃生。他们约好在土耳其浴室见面，并用这次行动的代号“鸳鸯茶”作为接头暗号。
他们分别降落在法国巴黎德军占领区的不同地点。大胡子中队长雷金纳德被动物园管理员所救。而另外两名士兵，也分别在油漆匠奥古斯德 （布尔维尔 饰）和乐队指挥斯塔尼斯拉斯（路易·德·费内斯 饰）的帮助下掩藏好了。即便德军展开了全城的搜索，油漆匠、指挥和中队长还是在浴室顺利地会面，几经辗转，英国士兵终于接上了头。几个原本并不认识的人，就这样结成了生死同盟，与敌人展开了斗智斗勇的生死游戏。同时，也闹出了不少温情的笑话。他们用微薄的力量对抗严酷德军，险相迭生，滑稽搞笑，为了逃出虎口，共同战斗。 ©豆瓣

## 虎口脱险的演职员 · · · · · · ( 全部 43 )

- 热拉尔·乌里 导演
- 路易·德·菲奈斯 饰 Stanislas Lefort
- 布尔维尔 饰 Augustin Bouvet
- 克劳迪奥·布鲁克 饰 Peter Cunningham
- 安德丽·帕里西 饰 Soeur Marie-Odile / Sister Marie-Odile
- 科莱特·布罗塞 饰 Germaine

## 虎口脱险的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片332 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  拯救大兵瑞恩

  兵临城下

  黑鹰坠落

  钢琴家

  战争之王

  辛德勒的名单

  1917

  无耻混蛋

  全金属外壳

  穿条纹睡衣的男孩

我要写短评

## 虎口脱险的短评 · · · · · · ( 全部 46747 条 )

热门 / 最新 / 好友

### 801 有用 17950 看过 2006-10-12 17:42:13

娘的,这就是货真价实的喜剧片

### 376 有用 考拉 看过 2008-05-20 21:20:51

虽然不合理，但能够娱乐。

### 530 有用 mecca 看过 2010-01-18 07:11:09

这片子比<举起手来>高明在哪里？我想可能是它不止于愚化对手制造牵强笑料，而同时对阶层矛盾、异国文化之间的碰撞等喜点进行了密集捕捉&戏剧化的组织吧。不明高分9如何当得起，许因为是当年译制片中少有这种挤牙膏样头笑到尾还吊着胃口的喜剧？但说实话，<无耻混蛋>里的敌人迷人得多，戏也紧得多

### 862 有用 艾小柯 看过 2006-06-23 01:20:46

永远看不腻的喜剧！

### 183 有用 影志 看过 2019-06-20 13:06:35

“胜利属于我们” 没想到60年代就能产出如此纯粹的喜剧。

> 更多短评 46747条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 虎口脱险的影评 · · · · · · ( 全部 210 条 )

热门 / 最新 / 好友
侃叔 2016-04-14 12:59:57

## 人类史上最伟大的喜剧片，中国电影史上最棒的译制片

这篇影评可能有剧透

写给人类史上最伟大的喜剧片，『虎口脱险』，一部1400万法郎打造的恢宏巨著，一部喜剧界至今难以超越的传奇。 写给中国电影史上最棒的译制片，『虎口脱险』，一次凝聚了那一代最优秀老戏骨心血的配音，一部配音效果丝毫不输原声甚至更加精彩的影片。 今年，是她的50岁生日，中... (展开)
589 15 47回应 收起
Willing 2006-12-14 19:36:49

## 配音

上译厂的配音堪称完美,应该是空前绝后了.很怀念那些优秀的电影配音艺术家们,他们不知为我童年的电影梦想注入了多少曼妙的音符,激越的诗行,幼小的心灵因被这些声音灌溉而饱满润泽,那是记忆中最珍贵的收藏.童自荣,邱岳峰,乔榛,丁建华....他们才是中国电影的奇葩,是决绝到极至的永... (展开)
308 28 65回应 收起
奥利奥奶茶 2009-07-08 19:14:13

## 想起过年的时候，一家人笑得在沙发上滚作一团

电影频道，打开电视看电影。和爸爸妈妈一起。 直到现在，电影频道都是我最喜欢的台。尤其是佳片有约，那些片子不见得是最时髦的，却都当得起经典二字。虎口脱险，每到过年的时候都要约一约，对我们家来说，这是最最可乐最最经典的贺岁片。 经典场景很多啊，“鸳鸯茶，你和我。... (展开)
228 24 39回应 收起
瞎子 2007-09-26 01:43:33

## 我要长刷子，不要扁刷子

Fri Nov 12, 2004 我要长刷子，不要扁刷子 昨天晚上查了查天气预报，周末下雨。 看来油漆刷不成了。 想起《虎口脱险》里那个油漆匠，还有那句经典的台词：我要长刷子，不要扁刷子……这个你不懂。 是啊，离开心爱的人，或者半夜假装梦游求婚未成功，都是让人沮丧的。无法直说... (展开)
157 14 17回应 收起
有所思在大海南 2014-04-15 23:40:02

## 致侵略者与逃亡者——只有学好法语才混得下去

这篇影评可能有剧透

很小的时候在电影频道看过国语配音的《虎口脱险》，断断续续地看的，当时印象最深的是那个德军的斗鸡眼高射炮手，心想德军里怎么会有这么逗的人。 十多年后完整地又看了一遍原声的《虎口脱险》，印象最深的是碧眼狐狸Juliette，她微笑时，令人简直无法将视线从她... (展开)
122 7 20回应 收起
低端~ 2018-06-19 20:20:25

## 回溯经典，战争喜剧的巅峰

这篇影评可能有剧透

提起战争片，也许我们想起的是《拯救大兵瑞恩》的悲壮与惨烈，亦或是《血战钢锯岭》的信念，但是战争片也不一定是沉重的，就像我们也会有《举起手来》这样的战争喜剧。回溯电影历史，最出彩的仍然是这部经久不衰的法国战争喜剧——《虎口脱险》。 《虎口脱险》上映于1966年，由... (展开)
29 4回应 收起
黏我啊 2017-06-29 08:33:04

## 战争的残酷

很多都说本片用喜剧手法表现了战争的残酷，战争的残酷不一定要用血腥来表达～我不同意这种说法～ 我认为本片并未想表达战争的残酷～它只是想用戏剧的形式抚慰人的心灵，讽刺战争的无意义～ 在影片的最后，中队长和油漆匠，指挥家一行人在空中撑着滑翔机自由的飞翔也凸显了战争... (展开)
22 1 0回应 收起
防晒霜 2019-06-23 06:04:24

## 原声版《虎口脱险》的多国语言艺术

33年前，我读小学的时候，就在沈阳太原街的解放电影院看过《虎口脱险》，当时乐得我前仰后合，因为指挥家斯塔尼斯拉斯，因为油漆匠奥古斯特，因为美丽的朱丽叶特，因为德国大兵斗鸡眼，也因为上译厂的经典配音，尚华，于鼎，程晓桦，苏秀，还有身兼数角的乔榛和童自荣。 后来在... (展开)
16 5回应 收起
rock prince 2009-10-04 16:49:04

## 我写的《虎口脱险》影评

这篇影评可能有剧透

关于二战的喜剧片有很多,但只要提到二战喜剧，就不得不提《虎口脱险》！我第一次看《虎口脱险》的时候就连续看了两遍,以后更是不断回顾其中的经典镜头！我对电影拍摄手法和技巧并不专业，所以我不敢从拍摄的技术等方面来大侃，我只把我眼中的这部法国喜剧做一个简单的影评！ ... (展开)
21 4 7回应 收起
kidding 2017-05-28 08:44:10

## 一切发生的都很自然

本来电影就是虚构的，喜剧片更是要设计出无数的巧合，才会通篇充满笑点。笔者也认同这一点，但俗话说，天衣无缝，真正的神品是看不出人工斧凿之痕的，事情的发生都很自然，添一分太肥，减一分则过瘦。相反，过于明显的设计痕迹则会给观众的笑声打上几个折扣。所以说，笔者认为... (展开)
4 0回应 收起

> 更多影评 210篇

添加新讨论

## 讨论区 · · · · · ·

大家有get到笑点吗？ | 来自我的初恋是EG | 22 回应 | 2022-10-02 02:07:18
132分钟是啥时的版本了，还能找到吗 | 来自SilentHunter |  | 2022-09-06 08:18:54
门牌号码6和9弄错那段被后来好多电影借鉴过！ | 来自百年孤寂 | 9 回应 | 2022-08-19 15:17:23
译制片 | 来自飘 | 3 回应 | 2022-08-12 00:07:49
关于在澡堂偷的衣服 | 来自风不会停息 | 1 回应 | 2022-08-02 20:02:39

> 去这部影片的讨论区（全部98条）

## 关于《虎口脱险》的问题 · · · · · · ( 全部8个 )

- 最后汽车拉着飞机的绳子有解开吗？Bug吗？ 4人回答
- 环球旅馆那里的一个问题？ 0人回答

> 全部8个问题

## 在哪儿看这部电影 · · · · · ·

- 咪咕视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 1905电影网 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

## 谁在看这部电影 · · · · · ·

- Cloris雷菁
  刚刚 看过
- 解语花
  6分钟前 看过
- momo
  16分钟前 想看

350203人看过 / 154095人想看

订阅虎口脱险的评论:
feed: rss 2.0